<?php

/**
 * @file
 * The spin module's settings.
 */

const SPIN_AUTOSPIN_MAX = 70000;
const SPIN_AUTOSPIN_MIN = 5000;
const SPIN_AUTOSPIN_INC = 5000;
const SPIN_EFFECT_MAX = 1000;
const SPIN_EFFECT_MIN = 200;
const SPIN_EFFECT_INC = 50;

/**
 * The admin settings form.
 */
function spin_slideshow_settings_form($form_id, &$form_state) {
  $header = '<h2 style="background-color:#eeeeee; border:1px #aaaaaa solid; margin:1.0rem auto 0.1rem 0; padding:0.5rem; width:50%">@txt</h2>';
  $opts = array(
    'true'  => t('Yes'),
    'false' => t('No'),
  );
  $form['head_common'] = array(
    '#type'   => 'markup',
    '#markup' => t("$header", array('@txt' => 'Common')),
  );
  $form['spin_slideshow_orientation'] = array(
    '#title'         => t('Orientation'),
    '#description'   => t('Direction for slides (left/right or up/down).'),
    '#type'          => 'select',
    '#default_value' => variable_get('spin_slideshow_orientation', 'horizontal'),
    '#options'       => array(
      'horizontal' => t('Horizontal'),
      'vertical'   => t('Vertical'),
    ),
  );
  $form['spin_slideshow_arrows'] = array(
    '#title'         => t('Arrows'),
    '#description'   => t('Show navigation arrows on hover.'),
    '#type'          => 'select',
    '#default_value' => variable_get('spin_slideshow_arrows', 'true'),
    '#options'       => $opts,
  );
  $form['spin_slideshow_loop'] = array(
    '#title'         => t('Loop'),
    '#description'   => t('Continue slideshow after last slide.'),
    '#type'          => 'select',
    '#default_value' => variable_get('spin_slideshow_loop', 'false'),
    '#options'       => $opts,
  );
  $form['spin_slideshow_effect'] = array(
    '#title'         => t('Effect'),
    '#description'   => t('Slide transition effect.'),
    '#type'          => 'select',
    '#default_value' => variable_get('spin_slideshow_effect', 'slide'),
    '#options'       => array(
      'bars3d'       => t('Bars3d'),
      'blinds3d'     => t('Blinds3d'),
      'blocks'       => t('Blocks'),
      'cube'         => t('Cube'),
      'diffusion'    => t('Diffusion'),
      'dissolve'     => t('Dissolve'),
      'fade'         => t('Fade'),
      'fade-down'    => t('Down'),
      'fade-up'      => t('Up'),
      'flip'         => t('Flip'),
      'random'       => t('Random'),
      'slide'        => t('Slide'),
      'slide-change' => t('Change'),
      'slide-in'     => t('In'),
      'slide-out'    => t('Out'),
    ),
  );
  $form['spin_slideshow_effect_speed'] = array(
    '#title'         => t('Effect Speed'),
    '#description'   => t('Speed of slide transition effect.'),
    '#type'          => 'select',
    '#default_value' => variable_get('spin_slideshow_effect_speed', 600),
    '#options'       => array_combine(range(SPIN_EFFECT_MIN, SPIN_EFFECT_MAX, SPIN_EFFECT_INC), range(SPIN_EFFECT_MIN, SPIN_EFFECT_MAX, SPIN_EFFECT_INC)),
  );
  $form['head_autoplay'] = array(
    '#type'   => 'markup',
    '#markup' => t("$header", array('@txt' => 'Autoplay')),
  );
  $form['spin_slideshow_autoplay'] = array(
    '#title'         => t('Autoplay'),
    '#description'   => t('Autoplay slideshow after initialization.'),
    '#type'          => 'select',
    '#default_value' => variable_get('spin_slideshow_autoplay', 'false'),
    '#options'       => $opts,
  );
  $form['spin_slideshow_shuffle'] = array(
    '#title'         => t('Shuffle'),
    '#description'   => t('Shuffle slide order.'),
    '#type'          => 'select',
    '#default_value' => variable_get('spin_slideshow_shuffle', 'false'),
    '#options'       => $opts,
  );
  $form['spin_slideshow_pause'] = array(
    '#title'         => t('Pause'),
    '#description'   => t('Click to pause slideshow.'),
    '#type'          => 'select',
    '#default_value' => variable_get('spin_slideshow_pause', 'false'),
    '#options'       => $opts,
  );
  $form['head_selectors'] = array(
    '#type'   => 'markup',
    '#markup' => t("$header", array('@txt' => 'Selectors')),
  );
  $form['spin_slideshow_selectors'] = array(
    '#title'         => t('Selectors'),
    '#description'   => t('Where to show selectors.'),
    '#type'          => 'select',
    '#default_value' => variable_get('spin_slideshow_selectors', 'bottom'),
    '#options'       => array(
      'left'   => t('Left'),
      'top'    => t('Top'),
      'right'  => t('Right'),
      'bottom' => t('Bottom'),
      'none'   => t('None'),
    ),
  );
  $form['spin_slideshow_selectors_style'] = array(
    '#title'         => t('Selectors Style'),
    '#description'   => t('Style of selectors.'),
    '#type'          => 'select',
    '#default_value' => variable_get('spin_slideshow_selectors_style', 'thumbnails'),
    '#options'       => array(
      'bullets'    => t('Bullets'),
      'thumbnails' => t('Thumbnails'),
    ),
  );
  $form['spin_slideshow_selectors_eye'] = array(
    '#title'         => t('Selectors Eye'),
    '#description'   => t('Highlighter for active thumbnail.'),
    '#type'          => 'select',
    '#default_value' => variable_get('spin_slideshow_selectors_eye', 'false'),
    '#options'       => $opts,
  );
  $form['head_caption'] = array(
    '#type'   => 'markup',
    '#markup' => t("$header", array('@txt' => 'Caption')),
  );
  $form['spin_slideshow_caption'] = array(
    '#title'         => t('Caption'),
    '#description'   => t('Display text on a slide.'),
    '#type'          => 'select',
    '#default_value' => variable_get('spin_slideshow_caption', 'false'),
    '#options'       => $opts,
  );
  $form['spin_slideshow_caption_effect'] = array(
    '#title'         => t('Caption Effect'),
    '#description'   => t('Caption change with effect.'),
    '#type'          => 'select',
    '#default_value' => variable_get('spin_slideshow_caption_effect', 'fade'),
    '#options'       => array(
      'fade'     => t('Fade'),
      'dissolve' => t('Dissolve'),
      'fixed'    => t('Fixed'),
    ),
  );
  $form['head_other'] = array(
    '#type'   => 'markup',
    '#markup' => t("$header", array('@txt' => 'Other')),
  );
  $form['spin_slideshow_fullscreen'] = array(
    '#title'         => t('Fullscreen'),
    '#description'   => t('Full screen.'),
    '#type'          => 'select',
    '#default_value' => variable_get('spin_slideshow_fullscreen', 'true'),
    '#options'       => $opts,
  );
  $form['spin_slideshow_keyboard'] = array(
    '#title'         => t('Keyboard'),
    '#description'   => t('Keyboard navigation.'),
    '#type'          => 'select',
    '#default_value' => variable_get('spin_slideshow_keyboard', 'false'),
    '#options'       => $opts,
  );
  $form['spin_slideshow_preload'] = array(
    '#title'         => t('Preload'),
    '#description'   => t('Load images on demand.'),
    '#type'          => 'select',
    '#default_value' => variable_get('spin_slideshow_preload', 'true'),
    '#options'       => $opts,
  );
  $form['spin_slideshow_loader'] = array(
    '#title'         => t('Loader'),
    '#description'   => t('Show loading icon.'),
    '#type'          => 'select',
    '#default_value' => variable_get('spin_slideshow_loader', 'true'),
    '#options'       => $opts,
  );
  $form['spin_slideshow_links'] = array(
    '#title'         => t('Links'),
    '#description'   => t('Open links associated with image slides.'),
    '#type'          => 'select',
    '#default_value' => variable_get('spin_slideshow_links', ''),
    '#options'       => array(
      'false'  => t('No'),
      '_self'  => t('In the same page'),
      '_blank' => t('In a new tab/window'),
    ),
  );
  $form['#submit'][] = 'spin_slideshow_settings_submit';

  return system_settings_form($form);
}

/**
 * Custom submit hook.
 */
function spin_slideshow_settings_submit($form, &$state) {
  $options = array();

  foreach ($state['values'] as $field => $val) {
    if (!preg_match('/^spin_slideshow_(\w+)/', $field, $m)) {
      continue;
    }
    $options[str_replace('_', '-', $m[1])] = $val;
  }
  variable_set('spin_slideshow_data_options', $options);
}

/**
 * The admin settings form.
 */
function spin_spin_settings_form($form_id, &$form_state) {
  $header = '<h2 style="background-color:#eeeeee; border:1px #aaaaaa solid; margin:1.0rem auto 0.1rem 0; padding:0.5rem; width:50%">@txt</h2>';
  $opts = array(
    'true'  => t('Yes'),
    'false' => t('No'),
  );
  $form['head_autospin'] = array(
    '#type'   => 'markup',
    '#markup' => t("$header", array('@txt' => 'Autospin')),
  );
  $form['spin_spin_autospin'] = array(
    '#title'         => t('Autospin'),
    '#description'   => t('Automatically spin the image.'),
    '#type'          => 'select',
    '#default_value' => variable_get('spin_spin_autospin', 'once'),
    '#options'       => array(
      'off'      => t('Off'),
      'once'     => t('Once'),
      'twice'    => t('Twice'),
      'infinite' => t('infinite'),
    ),
  );
  $form['spin_spin_autospin_speed'] = array(
    '#title'         => t('Autospin Speed'),
    '#description'   => t('The time (ms) taken to complete 1 rotation.'),
    '#type'          => 'select',
    '#default_value' => variable_get('spin_spin_autospin_speed', 3500),
    '#options'       => array_combine(range(SPIN_AUTOSPIN_MIN, SPIN_AUTOSPIN_MAX, SPIN_AUTOSPIN_INC), range(SPIN_AUTOSPIN_MIN, SPIN_AUTOSPIN_MAX, SPIN_AUTOSPIN_INC)),
  );
  $form['spin_spin_autospin_start'] = array(
    '#title'         => t('Autospin Start'),
    '#description'   => t('Start autospin on page load, click or hover.'),
    '#type'          => 'select',
    '#default_value' => variable_get('spin_spin_autospin_start', 'load'),
    '#options'       => array(
      'click' => t('Click'),
      'hover' => t('Hover'),
      'load'  => t('Load'),
    ),
  );
  $form['spin_spin_autospin_stop'] = array(
    '#title'         => t('Autospin Stop'),
    '#description'   => t('Stop autospin on click, hover or never.'),
    '#type'          => 'select',
    '#default_value' => variable_get('spin_spin_autospin_stop', 'click'),
    '#options'       => array(
      'click' => t('Click'),
      'hover' => t('Hover'),
      'never' => t('Never'),
    ),
  );
  $form['spin_spin_autospin_direction'] = array(
    '#title'         => t('Autospin Direction'),
    '#description'   => t('Direction of spin.'),
    '#type'          => 'select',
    '#default_value' => variable_get('spin_spin_autospin_direction', 'clockwise'),
    '#options'       => array(
      'clockwise'     => t('Clockwise'),
      'anticlockwise' => t('Anticlockwise'),
    ),
  );
  $form['head_mouse'] = array(
    '#type'   => 'markup',
    '#markup' => t("$header", array('@txt' => 'Mouse')),
  );
  $form['spin_spin_spin'] = array(
    '#title'         => t('Spin Method'),
    '#description'   => t('Method for spinning the image.'),
    '#type'          => 'select',
    '#default_value' => variable_get('spin_spin_spin', 'drag'),
    '#options'       => array(
      'drag'  => t('Drag'),
      'hover' => t('Hover'),
    ),
  );
  $form['spin_spin_speed'] = array(
    '#title'         => t('Drag Speed'),
    '#description'   => t('Speed of spin while dragging (100 = fast).'),
    '#type'          => 'select',
    '#default_value' => variable_get('spin_spin_speed', 50),
    '#options'       => array_combine(range(0, 100, 5), range(0, 100, 5)),
  );
  $form['spin_spin_zoom'] = array(
    '#title'         => t('Zoom'),
    '#description'   => t('Zoom level on click (0 = disabled).'),
    '#type'          => 'select',
    '#default_value' => variable_get('spin_spin_zoom', 3),
    '#options'       => array_combine(range(0, 10), range(0, 10)),
  );
  $form['spin_spin_right_click'] = array(
    '#title'         => t('Right Click'),
    '#description'   => t('Show right-click menu on the image.'),
    '#type'          => 'select',
    '#default_value' => variable_get('spin_spin_right_click', 'false'),
    '#options'       => $opts,
  );
  $form['head_misc'] = array(
    '#type'   => 'markup',
    '#markup' => t("$header", array('@txt' => 'Misc')),
  );
  $form['spin_spin_fullscreen'] = array(
    '#title'         => t('Fullscreen'),
    '#description'   => t('Enable full-screen spin if large images exist.'),
    '#type'          => 'select',
    '#default_value' => variable_get('spin_spin_fullscreen', 'true'),
    '#options'       => $opts,
  );
  $form['spin_spin_initialize_on'] = array(
    '#title'         => t('Image Download'),
    '#description'   => t('When to download the images.'),
    '#type'          => 'select',
    '#default_value' => variable_get('spin_spin_initialize_on', 'load'),
    '#options'       => array(
      'click' => t('Click'),
      'hover' => t('Hover'),
      'load'  => t('Load'),
    ),
  );
  $form['#submit'][] = 'spin_spin_settings_submit';

  return system_settings_form($form);
}
/**
 * Custom submit hook.
 */
function spin_spin_settings_submit($form, &$state) {
  $options = array();

  foreach ($state['values'] as $field => $val) {
    if (!preg_match('/^spin_spin_(\w+)/', $field, $m)) {
      unset($state['values'][$field]);
      continue;
    }
    $key = preg_replace_callback('/_[a-z]/', function ($m) { return strtoupper($m[0]{1}); }, $m[1]);

    $options[$key] = $val;
  }
  variable_set('spin_spin_data_options', $options);
}
